@@ -190,9 +190,9 @@ def run_art(exe, params, seqSys, fasta, ofile, read_len, library, debug):
             cmd = "{exe} {params} -p -c 1 -ss {seqSys} -l {read_len} -amp -na -o {ofile} -i {fasta}"
     elif library == "se":
         if params["--qprof1"] and params["--qprof2"]:
-            cmd = "{exe} {params} -c 1 -l {read_len} -amp -na -o {ofile} -i {fasta}"
+            cmd = "{exe} {params} -c 1 -l {read_len} -amp -na -o {ofile}SR -i {fasta}"
         else:
-            cmd = "{exe} {params} -c 1 -ss {seqSys} -l {read_len} -amp -na -o {ofile} -i {fasta}"
+            cmd = "{exe} {params} -c 1 -ss {seqSys} -l {read_len} -amp -na -o {ofile}SR -i {fasta}"
 
     cmd = cmd.format(
         exe=exe,
@@ -334,16 +334,14 @@ def prepare_data_fragments(
 
     fragment_data = {}
 
-    fragSim_fname = f"{comm}---{taxon}___fragSim-{frag_type}"
+    fragSim_fname = f"{comm}---{taxon}___fragSim-{frag_type}{fragSim_frag_suffix}"
 
     fragments = pd.DataFrame(x[entry]["fragments"])
 
     fragment_data["seq_depth"] = x[entry]["seq_depth"]
 
     # Save fragmets
-    fragment_data["fragSim_frag_ofile"] = Path(tmp_dir, fragSim_fname).with_suffix(
-        fragSim_frag_suffix
-    )
+    fragment_data["fragSim_frag_ofile"] = Path(tmp_dir, fragSim_fname)
 
     fragments.to_csv(
         path_or_buf=fragment_data["fragSim_frag_ofile"],
@@ -351,26 +349,22 @@ def prepare_data_fragments(
         header=False,
         index=False,
     )
+    fragSim_fname = f"{comm}---{taxon}___fragSim-{frag_type}{fa_suffix_gz}"
+    fragment_data["fragSim_ofile"] = Path(tmp_dir, fragSim_fname)
 
-    fragment_data["fragSim_ofile"] = Path(tmp_dir, fragSim_fname).with_suffix(
-        fa_suffix_gz
+    deamSim_mis_fname = (
+        f"{comm}---{taxon}___deamSim_misincorporation-{frag_type}{txt_suffix}"
     )
 
-    deamSim_mis_fname = f"{comm}---{taxon}___deamSim_misincorporation-{frag_type}"
+    fragment_data["deamSim_mis_ofile"] = Path(tmp_dir, deamSim_mis_fname)
 
-    fragment_data["deamSim_mis_ofile"] = Path(tmp_dir, deamSim_mis_fname).with_suffix(
-        txt_suffix
-    )
+    deamSim_fname = f"{comm}---{taxon}___deamSim-{frag_type}{fa_suffix_gz}"
 
-    deamSim_fname = f"{comm}---{taxon}___deamSim-{frag_type}"
+    fragment_data["deamSim_ofile"] = Path(tmp_dir, deamSim_fname)
 
-    fragment_data["deamSim_ofile"] = Path(tmp_dir, deamSim_fname).with_suffix(
-        fa_suffix_gz
-    )
+    adptSim_fname = f"{comm}---{taxon}___adptSim-{frag_type}{fa_suffix}"
 
-    adptSim_fname = f"{comm}---{taxon}___adptSim-{frag_type}"
-
-    fragment_data["adptSim_ofile"] = Path(tmp_dir, adptSim_fname).with_suffix(fa_suffix)
+    fragment_data["adptSim_ofile"] = Path(tmp_dir, adptSim_fname)
 
     art_fname = f"{comm}---{taxon}___art-{frag_type}."
 
@@ -392,23 +386,30 @@ def collect_file_names(
         r1 = f"{art_ofile}1.fq"
         r2 = f"{art_ofile}2.fq"
         sr = None
+        files = {
+            "comm": x["comm"],
+            "taxon": x["taxon"],
+            "frag_type": frag_type,
+            "fragSim_ofile": fragSim_ofile,
+            "deamSim_ofile": deamSim_ofile,
+            "adptSim_ofile": adptSim_ofile,
+            "art_ofile_r1": r1,
+            "art_ofile_r2": r2,
+        }
     else:
         r1 = None
         r2 = None
-        sr = "{art_ofile}fq"
+        sr = f"{art_ofile}SR.fq"
+        files = {
+            "comm": x["comm"],
+            "taxon": x["taxon"],
+            "frag_type": frag_type,
+            "fragSim_ofile": fragSim_ofile,
+            "deamSim_ofile": deamSim_ofile,
+            "adptSim_ofile": adptSim_ofile,
+            "art_ofile_sr": sr,
+        }
 
-        # Collect file names
-    files = {
-        "comm": x["comm"],
-        "taxon": x["taxon"],
-        "frag_type": frag_type,
-        "fragSim_ofile": fragSim_ofile,
-        "deamSim_ofile": deamSim_ofile,
-        "adptSim_ofile": adptSim_ofile,
-        "art_ofile_r1": r1,
-        "art_ofile_r2": r2,
-        "art_ofile_sr": sr,
-    }
     return files
 
 
@@ -693,7 +694,10 @@ def rename_reads(records, pattern, comm, taxon, frag_type, fastx, remove_adapter
         # 8: length
         # 9: damage positions in read
         if fastx == "fastq":
-            name = f"{comm}___{m1.group(1)}---{i}:{frag_type}:{m1.group(2)}:{m1.group(3)}:{m1.group(4)}:{m1.group(5)}:{m1.group(6)}/{m1.group(7)}"
+            if len(m1.groups()) >= 7:
+                name = f"{comm}___{m1.group(1)}---{i}:{frag_type}:{m1.group(2)}:{m1.group(3)}:{m1.group(4)}:{m1.group(5)}:{m1.group(6)}/{m1.group(7)}"
+            else:
+                name = f"{comm}___{m1.group(1)}---{i}:{frag_type}:{m1.group(2)}:{m1.group(3)}:{m1.group(4)}:{m1.group(5)}:{m1.group(6)}"
             if remove_adapters:
                 record = record[int(0) : int(m1.group(5))]
         elif fastx == "fasta":
@@ -716,16 +720,26 @@ def _combine_reads(read_files, output_dir, output_file, fastx, remove_adapters):
     output_file : str
         Output file path
     """
-    output_file = os.path.join(output_dir, output_file)
-
-    if fastx == "fastq":
-        p0 = re.compile("(\S+)---(\S+)___art-(\S+).\d.fq")
-        p1 = re.compile("(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?\-\d\/(\d)$")
-    elif fastx == "fasta":
-        p0 = re.compile("(\S+)---(\S+)___\S+-(\S+).fasta\S+")
-        p1 = re.compile("(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?")
-    with open(output_file, "w") as outFH:
+    output_file = os.path.join(output_dir, f"{output_file}.gz")
+    encoding = guess_type(output_file)[1]  # uses file extension
+    _open = partial(gzip.open, mode="wt") if encoding == "gzip" else open
+    with _open(output_file) as outFH:
         for in_file in read_files:
+            if fastx == "fastq":
+                if "SR" not in os.path.split(in_file)[1]:
+                    p0 = re.compile("(\S+)---(\S+)___art-(ancient|modern).\d.fq")
+                    p1 = re.compile(
+                        "(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?\-\d\/(\d)$"
+                    )
+                else:
+                    p0 = re.compile("(\S+)---(\S+)___art-(ancient|modern).SR.fq")
+                    p1 = re.compile(
+                        "(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?\-\d$"
+                    )
+            elif fastx == "fasta":
+                p0 = re.compile("(\S+)---(\S+)___\S+-(\S+).fasta\S+")
+                p1 = re.compile("(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?")
+
             m0 = re.match(p0, os.path.split(in_file)[1])
             comm = m0.group(1)
             taxon = m0.group(2)
@@ -762,7 +776,6 @@ def _combine_fastq_types(
     output_dir = os.path.join(output_dir, str(comm))
     if not os.path.isdir(output_dir):
         os.makedirs(output_dir, exist_ok=True)
-
     if "r1" in file_type:
         r1 = list(
             set(
@@ -774,7 +787,7 @@ def _combine_fastq_types(
         R1_files = _combine_reads(
             read_files=r1,
             output_dir=output_dir,
-            output_file=f"comm-{comm}_{suffix}.1.fq",
+            output_file=f"{comm}_{suffix}.1.fq",
             fastx="fastq",
             remove_adapters=remove_adapters,
         )
@@ -784,7 +797,6 @@ def _combine_fastq_types(
             "pair": "R1",
             "file": R1_files,
         }
-
     elif "r2" in file_type:
         r2 = list(
             set(
@@ -796,7 +808,7 @@ def _combine_fastq_types(
         R2_files = _combine_reads(
             read_files=r2,
             output_dir=output_dir,
-            output_file=f"comm-{comm}_{suffix}.2.fq",
+            output_file=f"{comm}_{suffix}.2.fq",
             fastx="fastq",
             remove_adapters=remove_adapters,
         )
@@ -806,6 +818,27 @@ def _combine_fastq_types(
             "pair": "R2",
             "file": R2_files,
         }
+    elif "sr" in file_type:
+        sr = list(
+            set(
+                [s[file_type] for s in data_modern]
+                + [s[file_type] for s in data_ancient]
+            )
+        )
+        sr = sorted(sr)
+        SR_files = _combine_reads(
+            read_files=sr,
+            output_dir=output_dir,
+            output_file=f"{comm}_{suffix}.fq",
+            fastx="fastq",
+            remove_adapters=remove_adapters,
+        )
+        files = {
+            "comm": comm,
+            "file_type": file_type.replace("_r2", ""),
+            "pair": "SR",
+            "file": SR_files,
+        }
     else:
         sr = list(
             set(
@@ -842,7 +875,7 @@ def _combine_fasta_types(
     SR_files = _combine_reads(
         read_files=sr,
         output_dir=output_dir,
-        output_file=f"comm-{comm}_{suffix}.fa",
+        output_file=f"{comm}_{suffix}.fa",
         fastx="fasta",
         remove_adapters=False,
     )
@@ -860,10 +893,12 @@ def combine_fastx_files(
     files = {
         "art_ofile_r1": "art",
         "art_ofile_r2": "art",
+        "art_ofile_sr": "art",
         "fragSim_ofile": "fragSim",
         "deamSim_ofile": "deamSim",
     }
-    if any(x in file_type for x in ["r1", "r2"]):
+
+    if any(x in file_type for x in ["r1", "r2", "sr"]):
         files = _combine_fastq_types(
             file_type=file_type,
             suffix=files[file_type],
@@ -993,6 +1028,8 @@ def get_ancient_reads(args):
     comms = list(
         set([s["comm"] for s in ancient_files] + [s["comm"] for s in modern_files])
     )
+    files = [item for item in ancient_files[0] if "file" in item]
+    files = [item for item in files if "adptSim" not in item]
 
     func = partial(
         combine_fastx_files,
@@ -1005,7 +1042,6 @@ def get_ancient_reads(args):
 
     log.info("Combining reads by sample...")
 
-    files = ["art_ofile_r1", "art_ofile_r2", "fragSim_ofile", "deamSim_ofile"]
     comm_files = list(itertools.product(comms, files))
     if debug is True:
         files = list(map(func, comm_files))
@@ -1045,7 +1081,7 @@ def get_ancient_reads(args):
     dir_name = Path(filename.name).parent
 
     suffix = ".json"
-    read_files_ofile = Path(dir_name, f"{file_name}_read-files").with_suffix(suffix)
+    read_files_ofile = Path(dir_name, f"{file_name}_read-files{suffix}")
 
     read_files_json = json.dumps(
         read_files, default=obj_dict, ensure_ascii=False, indent=4
@@ -1057,5 +1093,4 @@ def get_ancient_reads(args):
     log.info("Ancient synthetic reads generated.")
 
 
-
 # %%
